@@ -32,7 +32,7 @@ from pyams_pagelet.pagelet import pagelet_config
 from pyams_security.interfaces import ILocalUser, ISecurityManager, IUsersFolderPlugin, \
     IViewContextPermissionChecker
 from pyams_security.interfaces.base import MANAGE_SECURITY_PERMISSION
-from pyams_security_views.zmi import ISecurityManagerView
+from pyams_security_views.zmi import SecurityPluginsTable
 from pyams_security_views.zmi.plugin import SecurityPluginAddForm, SecurityPluginAddMenu, \
     SecurityPluginPropertiesEditForm
 from pyams_site.interfaces import ISiteRoot
@@ -61,7 +61,7 @@ from pyams_security_views import _  # pylint: disable=ungrouped-imports
 
 
 @viewlet_config(name='add-users-folder-plugin.menu',
-                context=ISiteRoot, layer=IAdminLayer, view=ISecurityManagerView,
+                context=ISiteRoot, layer=IAdminLayer, view=SecurityPluginsTable,
                 manager=IContextAddingsViewletManager, weight=40,
                 permission=MANAGE_SECURITY_PERMISSION)
 class UsersFolderPluginAddMenu(SecurityPluginAddMenu):
